import React from 'react';
import { TextProps as RNTextProps } from 'react-native';
import type { TypoName, UIKitTheme } from '../../types';
export interface RTLTextAlignSupportProps {
    /**
     * If `I18nManager.isRTL` is `true` and this value is enabled, the text will be aligned according to RTL if it starts in an RTL language.
     * In the case of the `Text` component, the alignment value is calculated based on `I18nManager.doLeftAndRightSwapInRTL`.
     * For the `TextInput` component, the alignment value is calculated as a physical alignment, unaffected by `I18nManager.doLeftAndRightSwapInRTL`.
     */
    supportRTLAlign?: boolean;
    /**
     * If you want to enable `supportRTLAlign` but are using nested `Text` components that are not simple text under the `Text` component, pass the original text here.
     */
    originalText?: string;
}
type TypographyProps = Partial<Record<TypoName, boolean>>;
export type TextProps = RNTextProps & TypographyProps & {
    color?: ((colors: UIKitTheme['colors']) => string) | string;
} & RTLTextAlignSupportProps;
declare const Text: ({ children, color, style, supportRTLAlign, originalText, ...props }: TextProps) => React.JSX.Element;
export default Text;
